from fireflyalgorithm.fireflyalgorithm import FireflyAlgorithm

__all__ = ["FireflyAlgorithm"]

__version__ = "0.4.0"
